@@ -1,9 +1,10 @@
 # -*- perl -*-
 
 #
+# $Id: Conf.pm,v 1.8 2008/07/21 06:40:10 eserte Exp $
 # Author: Slaven Rezic
 #
-# Copyright (C) 2006,2008,2009,2012,2014,2015,2017 Slaven Rezic. All rights reserved.
+# Copyright (C) 2006,2008 Slaven Rezic. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -13,7 +14,7 @@
 
 package XTerm::Conf;
 
-use 5.006; # qr, autovivified filehandles
+use 5.005; # qr
 
 # Plethora of xterm control sequences:
 # http://rtfm.etla.org/xterm/ctlseq.html
@@ -21,14 +22,14 @@ use 5.006; # qr, autovivified filehandles
 use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 
-$VERSION = '0.11_50';
+$VERSION = '0.01';
 
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT    = qw(xterm_conf);
-@EXPORT_OK = qw(xterm_conf_string terminal_is_supported);
+@EXPORT_OK = qw(xterm_conf_string);
 
-use Getopt::Long 2.24; # OO interface
+use Getopt::Long;
 
 use constant BEL => "";
 use constant ESC => "";
@@ -73,20 +74,19 @@ sub xterm_conf_string {
     local @ARGV = @_;
 
     %o = ();
+    $need_reset_terminal++;
 
-    my $p = Getopt::Long::Parser->new;
-    $p->configure('no_ignore_case');
-    $p->getoptions(\%o,
-	       "iconname|n=s",
-	       "title|T=s",
+    GetOptions(\%o,
+	       "iconname=s",
+	       "title=s",
 	       "fg|foreground=s",
 	       "bg|background=s",
-	       "textcursor|cr=s",
-	       "mousefg|mouseforeground|ms=s",
+	       "textcursor=s",
+	       "mousefg|mouseforeground=s",
 	       "mousebg|mousebackground=s",
 	       "tekfg|tekforeground=s",
 	       "tekbg|tekbackground=s",
-	       "highlightcolor|hc=s",
+	       "highlightcolor=s",
 	       "bell",
 	       "cs=s",
 	       "fullreset",
@@ -123,8 +123,8 @@ sub xterm_conf_string {
 	       "debugreport",
 	       "resize=i",
 	      )
-	or _usage();
-    die _usage() if (@ARGV);
+	or die "usage?";
+    die "usage?" if (@ARGV);
 
     my $rv = "";
 
@@ -234,24 +234,11 @@ sub xterm_conf_string {
 }
 
 sub xterm_conf {
-    # always call xterm_conf_string(), so option validation is done
+    return if !$ENV{TERM};
+    return if $ENV{TERM} !~ m{^xterm};
     my $rv = xterm_conf_string(@_);
-    if (terminal_is_supported()) {
-	local $| = 1;
-	print $rv;
-    }
-}
-
-sub terminal_is_supported {
-    my($term) = @_;
-    $term = $ENV{TERM} if !defined $term;
-    if (!$ENV{TERM}) {
-	0;
-    } elsif ($ENV{TERM} !~ m{^(xterm|rxvt)}) {
-	0;
-    } else {
-	1;
-    }
+    local $| = 1;
+    print $rv;
 }
 
 sub _report ($$) {
@@ -260,41 +247,20 @@ sub _report ($$) {
     require Term::ReadKey;
     Term::ReadKey::ReadMode(5);
 
+    my $debug = $o{debugreport};
+
+    open my $TTY, "+< /dev/tty" or die "Cannot open terminal /dev/tty: $!";
+    syswrite $TTY, $cmd;
+    my $res = "";
     my @args;
-
-    eval {
-	require IO::Select;
-
-	my $debug = $o{debugreport};
-
-	open my $TTY, "+< /dev/tty" or die "Cannot open terminal /dev/tty: $!";
-	syswrite $TTY, $cmd;
-
-	my $sel = IO::Select->new;
-	$sel->add($TTY);
-
-	my $res = "";
-	while() {
-	    my(@ready) = $sel->can_read(5);
-	    if (!@ready) {
-		die "Cannot report, maybe allowWindowOps is set to false?";
-		last;
-	    }
-	    sysread $TTY, my $ch, 1 or die "Cannot sysread: $!";
-	    print STDERR ord($ch)." " if $debug;
-	    $res .= $ch;
-	    last if (@args = $res =~ $rx);
-	}
-
-	1;
-    };
-    my $err = $@;
+    while() {
+	sysread $TTY, my $ch, 1 or die "Cannot sysread: $!";
+	print STDERR ord($ch)." " if $debug;
+	$res .= $ch;
+	last if (@args = $res =~ $rx);
+    }
 
     Term::ReadKey::ReadMode(0);
-
-    if ($err) {
-	die "$err\n";
-    }
     @args;
 }
 
@@ -304,28 +270,12 @@ sub _report_windowpos   { _report CSI.'13t', qr{;(\d+);(\d+)t} }
 sub _report_geometry    { _report CSI.'14t', qr{;(\d+);(\d+)t} }
 sub _report_cgeometry   { _report CSI.'18t', qr{;(\d+);(\d+)t} }
 sub _report_cscreengeom { _report CSI.'19t', qr{;(\d+);(\d+)t} }
-sub _report_iconname    { _report CSI.'20t', qr{L(.*?)(?:\Q@{[ST]}\E|\Q@{[ST_8]}\E)} }
+sub _report_iconlabel   { _report CSI.'20t', qr{L(.*?)(?:\Q@{[ST]}\E|\Q@{[ST_8]}\E)} }
 sub _report_title       { _report CSI.'21t', qr{l(.*?)(?:\Q@{[ST]}\E|\Q@{[ST_8]}\E)} }
 
-sub _usage {
-    die <<EOF;
-usage: $0 [-n|iconname string] [-T|title string] [-cr|textcursor color]
-        [-fg|-foreground color] [-bg|-background color color]
-        [-ms|mousefg|-mouseforeground color] [-mousebg|-mousebackground color]
-        [-tekfg|-tekforeground color] [-tekbg|-tekbackground color]
-        [-hc|highlightcolor color] [-bell] [-cs ...] [-fullreset] [-softreset]
-	[-[no]smoothscroll] [-[no]reverse|reversevideo], [-[no]origin]
-	[-[no]wraparound] [-[no]autorepeat] [-[no]formfeed] [-[no]showcursor]
-        [-[no]showscrollbar] [-[no]tektronix] [-[no]marginbell]
-	[-[no]reversewraparound] [-[no]backsendsdelete]
-        [-[no]bottomscrolltty] [-[no]bottomscrollkey]
-	[-[no]metasendsesc|metasendsescape] [-scrollregion ...]
-	[-deiconify] [-iconify] [-geometry x11geom] [-raise] [-lower]
-	[-refresh|x11refresh] [-maximize] [-unmaximize]
-	[-xproperty|x11property ...] [-font ...] [-nextfont] [-prevfont]
-	[-report ...] [-debugreport] [-resize ...]
-
-EOF
+END {
+    Term::ReadKey::ReadMode(0)
+	    if $need_reset_terminal && defined &Term::ReadKey::ReadMode;
 }
 
 return 1 if caller;
@@ -345,275 +295,217 @@ XTerm::Conf - change configuration of a running xterm
 
 =head1 DESCRIPTION
 
-XTerm::Conf provides functions to change some aspects of a running
-L<xterm> and compatible terminal emulators (e.g. L<rxvt> or L<urxvt>).
-
 =head2 xterm_conf(I<options ...>)
 
 The xterm_conf function (exported by default) checks first if the
-current terminal looks like an xterm, rxvt or urxvt (by looking at the
-C<TERM> environment variable) and prints the escape sequences for the
+current terminal looks like an xterm (by looking at the C<TERM>
+environment variable) and prints the escape sequences for the
 following options:
 
 =over
 
-=item C<-n I<string>>
+=item -iconname string
 
-=item C<-iconname I<string>>
+Change the name of the associated X11 icon.
 
-Change name of the associated X11 icon.
+=item -title string
 
-=item C<-T I<string>>
+Change the xterm's title bar.
 
-=item C<-title I<string>>
+=item -fg color
 
-Change xterm's title name.
+=item -foreground color
 
-=item C<-fg I<color>>
+Change the text color. You can use either X11 named colors or the
+#rrggbb notation.
 
-=item C<-foreground I<color>>
+=item -bg color
 
-Change text color. You can use either X11 named colors or the
-C<#I<rrggbb>> notation.
+=item -background color
 
-=item C<-bg I<color>>
+Change the background color
 
-=item C<-background I<color>>
+=item -textcursor ...
 
-Change background color.
+???
 
-=item C<-cr I<color>>
+=item -mousefg color
 
-=item C<-textcursor I<color>>
-
-Change cursor color.
-
-=item C<-ms I<color>>
-
-=item C<-mousefg I<color>>
-
-=item C<-mouseforeground I<color>>
+=item -mouseforeground color
 
 Change the foreground color of the mouse pointer.
 
-=item C<-mousebg I<color>>
+=item -mousebg color
 
-=item C<-mousebackground I<color>>
+=item -mousebackground color
 
 Change the background/border color of the mouse pointer.
 
-=item C<-tekfg I<color>>
+=item -tekfg color
 
-=item C<-tekforeground I<color>>
+=item -tekforeground color
 
-Change foreground color of Tek window.
+???
 
-=item C<-tekbg I<color>>
+=item -tekbg color
 
-=item C<-tekbackground I<color>>
+=item -tekbackground color
 
-Change background color of Tek window.
+???
 
-=item C<-highlightcolor I<color>>
+=item -highlightcolor color
 
-Change selection background color.
+???
 
-=item C<-bell>
+=item -bell
 
-Ring the bell (may be visual or audible, depending on configuration).
+Ring the bell (either visual or audible)
 
-=item C<-cs utf-8|iso-8859-1>
+=item -cs ...
 
-Switch charset. Valid values are C<utf-8> and C<iso-8859-1>.
+???
 
-=item C<-fullreset>
+=item -fullreset
 
 Perform a full reset.
 
-=item C<-softreset>
+=item -softreset
 
 Perform a soft reset.
 
-=item C<-[no]smoothscroll>
+=item -[no]smoothscroll
 
-Turn smooth scrolling on or off (which is probably the opposite of
-jump scroll, see L<xterm(1)>).
+Turn smooth scrolling on or off. Does not have a visual effect,
+though.
 
-=item C<-[no]reverse>
+=item -[no]reverse
 
-=item C<-[no]reversevideo>
+=item -[no]reversevideo
 
 Turn reverse video on or off.
 
-=item C<-[no]origin>
+=item -[no]origin
 
 ???
 
-=item C<-[no]wraparound>
+=item -[no]wraparound
 
 ???
 
-=item C<-[no]autorepeat>
+=item -[no]autorepeat
 
-Turn auto repeat on or off.
+Turn auto repeat on or off
 
-=item C<-[no]formfeed>
+=item -[no]formfeed
 
 ???
 
-=item C<-[no]showcursor>
+=item -[no]showcursor
 
-Show or hide the cursor.
+???
 
-=item C<-[no]showscrollbar>
+=item -[no]showscrollbar
 
 rxvt only?
 
-=item C<-[no]tektronix>
-
-Show the Tek window and switch to Tek mode (XXX C<-notektronix> does not
-seem to work).
-
-=item C<-[no]marginbell>
+=item -[no]tektronix
 
 ???
 
-=item C<-[no]reversewraparound>
+=item -[no]marginbell
 
 ???
 
-=item C<-[no]backsendsdelete>
+=item -[no]reversewraparound
 
 ???
 
-=item C<-[no]bottomscrolltty>
+=item -[no]backsendsdelete
+
+???
+
+=item -[no]bottomscrolltty
 
 rxvt only?
 
-=item C<-[no]bottomscrollkey>
+=item -[no]bottomscrollkey
 
 rxvt only?
 
-=item C<-[no]metasendsesc>
+=item -[no]metasendsesc
 
-=item C<-[no]metasendsescape>
+=item -[no]metasendsescape
 
 ???
 
-=item C<-scrollregion I<...>>
+=item -scrollregion ...
 
 ???
 
-=item C<-deiconify>
+=item -deiconify
 
 Deiconify an iconified xterm window.
 
-=item C<-iconify>
+=item -iconify
 
 Iconify the xterm window.
 
-=item C<-geometry I<geometry>>
+=item -geometry geomtry
 
 Change the geometry of the xterm window. The geometry is in the usual
 X11 notation I<width>xI<height>+I<left>+I<top>. The numbers are in
 pixels. The width and height may be suffixed with a C<c>, which means
-that the numbers are interpreted as characters.
+that the number are interpreted as characters.
 
-=item C<-raise>
+=item -raise
 
 Raise the xterm window.
 
-=item C<-lower>
+=item -lower
 
 Lower the xterm window
 
-=item C<-refresh>
+=item -refresh
 
-=item C<-x11refresh>
+=item -x11refresh
 
-Force a X11 refresh.
+Force a X11 refresh
 
-=item C<-maximize>
+=item -maximize
 
-Maximize the xterm window.
+Maximize the xterm window
 
-=item C<-unmaximize>
+=item -unmaximize
 
 Restore to the state before maximization.
 
-=item C<-xproperty I<...>>
+=item -xproperty ...
 
-=item C<-x11property I<...>>
+=item -x11property ...
 
 ???
 
-=item C<-font I<number>>
-
-Change font. Number may be from 0 (default font) to 6 (usually the
-largest font, but this could be changed using Xdefaults).
-
-=item C<-nextfont>
-
-Use the next font in list.
-
-=item C<-prevfont>
-
-Use the previous font in list.
-
-=item C<-report I<what>>
-
-Report to C<STDOUT>:
-
-=over
-
-=item C<status>
-
-Return 1.
-
-=item C<cursorpos>
-
-The cursor position (I<line column>).
-
-=item C<windowpos>
-
-The XTerm window position (I<x y>).
-
-=item C<geometry>
-
-The geometry of the window in pixels (I<width> I<height>).
-
-=item C<cgeometry>
-
-The geometry of the window in characters (I<width>C<x>I<height>).
-
-=item C<cscreengeom>
+=item -font ...
 
 ???
 
-=item C<iconname>
+=item -nextfont
 
-The icon name. This may only be available if the allowWindowOps
-resource is set to true (e.g. using
+???
 
-    xterm -xrm "*allowWindowOps:true"
+=item -prevfont
 
-). On some operating systems and some terminal emulators (most notable
-C<rxvt> on Debian/Ubuntu systems) this operation may be forbidden
-completely.
+???
 
-=item C<title>
+=item -report ...
 
-The title name. See L</iconname> for possible restrictions on
-availability.
+???
 
-=back
+=item -debugreport
 
-=item C<-debugreport>
+???
 
-If set together with a C<-report ...> option, then print the returned
-escape sequence as numbers to C<STDOUT> (as an debugging aid).
-
-=item C<-resize I<integer>>
+=item -resize integer
 
 ???
 
@@ -627,19 +519,12 @@ performed here.
 
 xterm_conf_string may be exported.
 
-=head2 terminal_is_supported(I<term>)
-
-Return a true value if the given I<term>, or if missing, the current
-terminal as given by C<$ENV{TERM}>, is supported.
-
-This function may be exported.
-
 =head1 AUTHOR
 
 Slaven ReziE<0x107>
 
 =head1 SEE ALSO
 
-L<xterm-conf>, L<xterm(1)>, L<rxvt(1)>, L<Term::Title>.
+L<Term::Title>, L<xterm(1)>.
 
 =cut
